"""
from bloonix.benchmark import benchmark

def func_1():
    "-".join(str(n) for n in range(100))

def func_2():
    "-".join(str(n) for n in range(200))

benchmark(10000, {
    "func_1": func_1,
    "func_2": func_2
})
"""

import timeit

def benchmark(count, funcs):
    result = []
    length = 0

    for alias in funcs:
        if len(alias) > length:
            length = len(alias)

    prefix = "%-" + str(length) + "s took "
    print("\nStart benchmark:\n")

    for alias in sorted(funcs.keys()):
        print(prefix % alias, end="")
        time = timeit.timeit(funcs[alias], number=count)
        rate = "%.3f/s" % (count / time)
        print("%.6fs @ %18s (n=%s)" % (time, rate, count))
        result.append({"time": time, "alias": alias, "rate": rate})

    print("\nResult:\n")

    line_prefix = "%-" + str(length) + "s  %18s  "

    if length > 10:
        col_prefix = "%" + str(length) + "s  "
    else:
        col_prefix = "%10s  "

    print(line_prefix % ("", "Rate"), end="")
    for res in result:
        print(col_prefix % res["alias"], end="")

    print()
    for x in result:
        print(line_prefix % (x["alias"], x["rate"]), end="")
        for y in result:
            if x["alias"] == y["alias"]:
                print(col_prefix % "--", end="")
            else:
                c = y["time"] * 100 / x["time"] - 100
                c = format(c, ".1f") + "%"
                print(col_prefix % c, end="")
        print()
    print()
