"""
With this module it's possible to search for python modules
within a directory. Allowed characters for the filenames are

    a-z 0-9

and the file must begin with a character of a-z.

* load_path(directory)

    Search for python modules on the first level of the directory.
    As example if the directory is /srv/myapp then the following
    modules will be returned:

        /srv/myapp/a/__init__.py
        /srv/myapp/b/__init__.py
        /srv/myapp/c.py
        /srv/myapp/d.py

    But not

        /srv/myapp/c/d/__init__.py
        /srv/myapp/c/d/f.py

* load_path(directory, deep=True)

    Search for all python modules recursive.

"""

import os
import re

def load_path(listdir, deep=False):
    file_regex = r"^[a-z][a-z0-9_]*\.py\Z"
    dir_regex = r"^[a-z][a-z0-9_]*\Z"
    paths = []
    _load_path(listdir, file_regex, dir_regex, paths, deep)
    return paths

def _load_path(basedir, file_regex, dir_regex, paths, deep, add_path=None):
    listdir = basedir if add_path is None else "%s/%s" % (basedir, add_path)

    for f in os.listdir(listdir):
        file_path = "%s/%s" % (listdir, f)
        init_file = "%s/%s" % (file_path, "__init__.py")
        module_name = f

        if add_path is not None:
            module_name = "%s/%s" % (add_path, f)

        if os.path.isdir(file_path) and re.search(dir_regex, f):
            if os.path.isfile(init_file):
                paths.append(module_name)

            if deep is True:
                if add_path is not None:
                    f = "%s/%s" % (add_path, f)
                _load_path(basedir, file_regex, dir_regex, paths, deep, f)
                    
        elif os.path.isfile(file_path) and re.search(file_regex, f):
            module_name = re.sub(r"\.py\Z", "", module_name)
            paths.append(module_name)
