from bloonix.logger import logger
from bloonix.findmod import load_path
import importlib
import os
import re

class Plugin:
    def __init__(self, heaven):
        self.log = logger("bloonix")
        self.heaven = heaven
        from bloonix.heaven.plugin.error import Error
        from bloonix.heaven.plugin.token import Token
        from bloonix.heaven.plugin.table import Table
        self.error = Error()
        self.table = Table()
        self.token = Token()

    def autoload(self):
        paths = load_path("%s/%s" % (self.heaven.app_path, "plugin"))
        for p in paths:
            self.load(p)

    def load(self, *args):
        for arg in args:
            p = re.split(":", arg)
            module_name = p[0]
            class_name = None
            if len(p) == 2:
                class_name = p[1]
            else:
                def replace(m):
                    return m.group(1).upper()
                class_name = re.sub(r"_([a-z])", replace, p[0])
                class_name = re.sub(r"^([a-z])", replace, class_name)
            self._load(module_name, class_name)

    def _load(self, name, class_name):
        accessor = re.sub(r"[^a-zA-Z_0-9]", "_", name)
        accessor = accessor.lower()
        module_name = "%s.plugin.%s" % (self.heaven.app_name, name)
        self.log.notice("load plugin", module_name)
        module = importlib.import_module(module_name)
        attr = getattr(module, class_name)
        if name in self.heaven._config["plugin"]:
            instance = attr(self.heaven._config["plugin"][name])
        else:
            instance = attr()
        setattr(self, accessor, instance)
