from bloonix.logger import logger
import re
import time

class Response:
    def __init__(self, start_response):
        self.start_response = start_response
        self.log = logger("bloonix")
        self.status = "200 OK"
        self.content_type = False
        self.http_header = {}
        self.content = ""
        self.binary = False

    def header(self, param, value):
        if param in self.http_header:
            if not isinstance(self.http_header, list):
                self.http_header[param] = [self.http_header[param]]
            self.http_header[param].append(value)
        else:
            self.http_header[param] = value

    def process(self):
        if not self.content_type:
            self.content_type = "text/html; charset=utf-8"

        self.log.info("res: %s: %s" % ("Content-Type", self.content_type))
        header = [("Content-Type", self.content_type)]

        for param in self.http_header:
            if isinstance(self.http_header[param], list):
                for item in self.http_header[param]:
                    self.log.info("response: %s: %s" % (param, item))
                    header.append((param, item))
            else:
                self.log.info("response: %s: %s" % (
                    param, self.http_header[param]))
                header.append((param, self.http_header[param]))

        self.log.info("res: Content-Length: %s bytes" % len(self.content))
        self.log.info("res: http status %s" % self.status)
        self.start_response(self.status, header)

        if self.binary is True:
            return self.content

        return bytes(self.content, "utf-8")

    def redirect(self, path, status="302 Found"):
        self.status = status
        self.header("Location", path)

    def cookie(self, name, value, expires=None,
            path="/", domain=None, secure=True,
            same_site="strict", http_only=True):
        cookie = []
        cookie.append("%s=%s" % (name, value))

        if expires:
            t = 0
            if isinstance(expires, int):
                t = int(time.time()) + expires
            else:
                m = re.search(r"^(-|\+)(\d+)([mhd]|)\Z", expires)
                if m:
                    c, n, u = m.group(1), m.group(2), m.group(3)
                    if u == "m":
                        n = int(n) * 60
                    elif u == "h":
                        n = int(n) * 3600
                    elif u == "d":
                        n = int(n) * 86400
                    else:
                        n = int(n)
                    t = int(time.time())
                    if c == "+":
                        t += n
                    else:
                        t -= n
            timestamp = time.strftime(
                "%a, %d %b %Y %H:%M:%S +0000", time.gmtime(t))
            cookie.append("%s=%s" % ("Expires", timestamp))

        if domain is not None:
            cookie.append("Domain=%s" % domain)
        if http_only is True:
            cookie.append("HttpOnly")
        if secure is True:
            cookie.append("Secure")
        if same_site is not None:
            cookie.append("SameSite=%s" % same_site)
        cookie.append("Path=%s" % path)
        self.header("Set-Cookie", "; ".join(cookie))
