import inspect
import re
from bloonix.json import json
from bloonix.logger import logger

class Routing:
    def __init__(self, heaven):
        self._caller = None
        self._routes = {}
        self._actions = {}
        self._id_regex = r"^([1-9]\d*)\Z"
        self.log = logger("bloonix")
        self.heaven = heaven

    def route(self, url_path, action, args=None):
        url_path = re.sub(r"^/", "", url_path)
        url_path = re.sub(r"/\Z", "", url_path)
        paths = url_path.split("/")
        action, module = self._get_module(action)
        routes = self._routes

        for path in paths:
            option = None
            regex = None
            _type = None

            if re.search(r"^:", path):
                key = "match"
                option, regex, _type = self._match_route_part(path)
            else:
                key = "route"

            if key not in routes:
                routes[key] = {}

            if path in routes[key]:
                routes = routes[key][path]
            else:
                routes[key][path] = {}
                routes = routes[key][path]
                if option is not None:
                    routes["option"] = option
                    routes["regex"] = regex
                    routes["type"] = _type

        routes["module"] = module
        routes["action"] = action
        routes["args"] = args

        if module not in self._actions:
            self._actions[module] = []

        self._actions[module].append(action)

    def _match_route_part(self, path):
        # :id, :user_id
        m = re.search(r"^:(id|[\w]+_id)\Z", path)
        if m:
            return m.group(1), self._id_regex, "int"

        # :user_name(regex)
        m = re.search(r"^:(\w+)(\(.*\))\Z", path)
        if m:
            return m.group(1), re.compile(r"^%s\Z" % m.group(2)), None

        # :any_key
        m = re.search(r"^:(\w+)\Z", path)
        if m:
            return m.group(1), re.compile(r"^([^\s\/]+)\Z"), None

        # :no_capture
        m = re.search(r"^:(\(.*\))\Z", path)
        if m:
            return None, re.compile(r"^%s\Z" % m.group(1)), None

        return None, None, None

    def actions(self, module=None):
        if module is not None:
            return self._actions[module]
        return self._actions

    def parse(self, path):
        self.log.debug("parse route:", path)
        path = re.sub(r"^/", "", path)
        path = re.sub(r"/\Z", "", path)
        path = path.split("/")
        opts = {}
        routes = self._routes

        while len(path):
            part = path.pop(0)
            self.log.debug("check route part:", part)
            self.log.debug(routes, dump=True)

            if "route" in routes and part in routes["route"]:
                self.log.debug("found route:", part)
                routes = routes["route"][part]
                continue

            hit = False

            if "match" in routes:
                matches = routes["match"]
                for opt in matches:
                    m = re.search(matches[opt]["regex"], part)
                    if m:
                        option = matches[opt]["option"]
                        self.log.debug("found match:", opt, "=",
                            part, "option", option)
                        if option is not None:
                            if "type" in matches[opt] and matches[opt]["type"] == "int":
                                opts[option] = int(m.group(1))
                            else:
                                opts[option] = m.group(1)
                        routes = matches[opt]
                        hit = True
                        break

            if hit is False:
                return None, None, None, None

        if "module" not in routes:
            return None, None, None, None

        if self.log.is_debug():
            self.log.debug(
                "got route %s -> %s"
                % (routes["module"], routes["action"]))
            self.log.debug("route options", opts)

        return routes["module"], routes["action"], opts, routes["args"]

    def _get_module(self, action):
        if re.search(r"\.", action):
            parts = action.split(".")
            action = parts.pop()
            module = ".".join(parts)
        else:
            for i in range(3):
                frame = inspect.stack()[i]
                module = inspect.getmodule(frame[0])
                module = module.__name__
                r = r"%s\.controller\." % self.heaven.app_name
                if re.search(r, module):
                    break

        return action, module
