from bloonix.logger import logger
from bloonix.findmod import load_path
import importlib
import os
import re

class View:
    def __init__(self, heaven):
        self.heaven = heaven
        self.log = logger("bloonix")
        self.views = {}
        self.load_base_views()

    def load_base_views(self):
        for v in ["jinja", "json", "plain"]:
            module_name = "bloonix.heaven.view.%s" % v
            self.log.notice("load base view", module_name)
            module = importlib.import_module(module_name)
            attr = getattr(module, "View")
            instance = attr(self.heaven)
            self.views[v] = instance

    def autoload(self):
        paths = load_path("%s/%s" % (self.heaven.app_path, "view"))
        for p in paths:
            self.load(p)

    def load(self, *args):
        for arg in args:
            self._load(arg)

    def _load(self, name):
        module_name = "%s.view.%s" % (self.heaven.app_name, name)
        self.log.notice("load view", module_name)
        module = importlib.import_module(module_name)
        attr = getattr(module, "View")

        if name in self.heaven._config["view"]:
            instance = attr(self.heaven._config["view"][name])
        else:
            instance = attr()

        if not hasattr(instance, "process"):
            raise Exception("missing mandatory method 'process' in view", module_name)

        accessor = re.sub(r"[^a-zA-Z_0-9]", "_", name)
        accessor = name.lower()
        self.views[accessor] = instance

    def process(self):
        if self._render_view:
            self.log.info("process view %s" % self._render_view)
            view = self.views[self._render_view]
            view.process()

    def render(self, view):
        if view not in self.views:
            raise Exception("view", view, "does not exists")
        self._render_view = view

    def reset(self):
        self._render_view = None
