import http.client
import re
import ssl
from base64 import b64encode
from bloonix.json import json
from bloonix.http.utils import (
    parse_url,
    quote_url_path,
    quote_data,
    header_to_dict)

def request(*args, **kwargs):
    return Client(*args, **kwargs)


class Client:
    def __init__(
            self, url, data=None, data_urlencode=None, user_agent="-",
            auth_basic=None, header=None, insecure=None, timeout=60,
            max_read_len=10485760):

        self.status = None
        self.headers = {}
        self.content = b""
        self.has_failed = None
        self.error = None

        if data and data_urlencode:
            raise Exception("mixin data with data_urlencode is invalid")

        scheme, host, port, path, qs, frag = parse_url(url)
        path = quote_url_path(path)
        header = header_to_dict(header)

        if qs:
            path = "%s?%s" % (path, qs)

        if data or data_urlencode:
            method = "POST"
        else:
            method = "GET"

        if user_agent and "user-agent" not in header:
            header["user-agent"] = user_agent

        if auth_basic and "authorization" not in header:
            auth_basic = bytes(auth_basic, "utf-8")
            auth_basic = b64encode(auth_basic).decode("ascii")
            header["authorization"] = "Basic %s" % auth_basic

        if data_urlencode:
            data = quote_data(data_urlencode)
            if "content-type" not in header:
                header["content-type"] = "application/x-www-form-urlencoded"

        if data:
            if isinstance(data, (dict, list)):
                data = json.dumps(data)
            if not isinstance(data, bytes):
                data = bytes(data, "utf-8")

        opts = {
            "host": host,
            "port": port,
            "timeout": timeout}

        if scheme == "https":
            client =  http.client.HTTPSConnection
            if insecure:
                opts["context"] = ssl._create_unverified_context()
        else:
            client = http.client.HTTPConnection

        conn = client(**opts)

        try:
            conn.request(method, path, body=data, headers=header)
            res = conn.getresponse()
            self.status = res.status
            for k, v in res.getheaders():
                self.headers[k.lower()] = v
            if max_read_len > 16384:
                block_size = 16384
            else:
                block_size = max_read_len
            data = b""
            while True:
                _data = res.read(block_size)
                if not _data:
                    break
                if max_read_len > 0 and len(_data) + len(data) > max_read_len:
                    conn.close()
                    raise Exception(
                        "body too long - max %s bytes allowed"
                        % max_read_len)
                data += _data

            self.content = data
            if "content-type" in self.headers:
                content_type = self.headers["content-type"].lower()
                m = re.search(r"charset=(\S+)", content_type)
                if m:
                    self.content = data.decode(m.group(1))
                else:
                    # If no charset is set, then we try at least
                    # to decode the content with default iso-8859-1
                    # if content-type is set to any type of text.
                    m = re.search("^text/", content_type)
                    if m:
                        try: self.content = data.decode("iso-8859-1")
                        except Exception: pass
        except Exception as err:
            self.has_failed = True
            self.error = err
        finally:
            conn.close()
