import os
import stat
import platform
if platform.system() != "Windows":
    import grp
    import pwd

from bloonix.validator import validate

class FileOutput:
    def __init__(self, opts):
        self.validate(opts)
        self.opts = opts

    def validate(self, opts):
        validate(opts, {
            "filename": {
                "type": str,
                "optional": True
            },
            "permissions": {
                "type": str,
                "default": "640"
            },
            "user": {
                "type": str,
                "optional": True,
            },
            "group": {
                "type": str,
                "optional": True,
            },
            "close": {
                "type": bool,
                "default": False,
            }
        })
        opts["permissions"] = int(opts["permissions"], 8)

    def log(self, message, level):
        self.check_file()
        fd = self.opts["fd"]
        os.write(fd, bytes(message + "\n", "utf-8"))
        if self.opts["close"] is True:
            self.close_file()

    def check_file(self):
        if "fd" not in self.opts or self.opts["fd"] is None:
            self.open_file()
            return

        try:
            stat = os.stat(self.opts["filename"])
            if stat.st_ino != self.opts["inode"]:
                self.close_file()
                self.open_file()
        except:
            self.close_file()
            self.open_file()

    def close_file(self):
        fd = self.opts["fd"]
        self.opts["fd"] = None
        os.close(fd)

    def open_file(self):
        self.opts["fd"] = os.open(
            self.opts["filename"],
            os.O_WRONLY | os.O_APPEND | os.O_CREAT,
            self.opts["permissions"])
        if platform.system() != "Windows":
            if self.opts["user"]:
                uid = pwd.getpwnam(self.opts["user"]).pw_uid
                if uid != os.stat(self.opts["filename"]).st_uid:
                    os.chown(self.opts["filename"], uid, -1)
            if self.opts["group"]:
                gid = grp.getgrnam(self.opts["group"]).gr_gid
                if gid != os.stat(self.opts["filename"]).st_gid:
                    os.chown(self.opts["filename"], -1, gid)
        stat = os.stat(self.opts["filename"])
        self.opts["inode"] = stat.st_ino
