import re
import socket
import subprocess
from email.mime.text import MIMEText
from bloonix.validator import validate

class MailOutput:
    def __init__(self, opts):
        self.validate(opts)
        self.opts = opts

    def validate(self, opts):
        validate(opts, {
            "subject": {
                "type": str,
            },
            "from": {
                "type": str,
            },
            "to": {
                "type": str,
            },
            "cc": {
                "type": str,
                "optional": True,
            },
            "bcc": {
                "type": str,
                "optional": True,
            },
        })

    def log(self, message, level):
        subject = self.opts["subject"]
        subject = re.sub(r"[\r\n]", " ", subject)
        subject = re.sub(r"%LEVEL%", level, subject)
        subject = re.sub(r"%HOSTNAME%", socket.gethostname(), subject)
        if len(subject) > 255:
            subject = subject[:255]

        msg = MIMEText(message)
        msg["From"] = self.opts["from"]
        msg["To"] = self.opts["to"]
        msg["Subject"] = subject
        if "cc" in self.opts:
            msg["Cc"] = self.opts["cc"]
        if "bcc" in self.opts:
            msg["Bcc"] = self.opts["bcc"]
        command = [
            "/usr/sbin/sendmail",
            "-t", "-oi" "-oem",
            "-f", self.opts["from"]]
        subprocess.run(command, input=msg.as_bytes())
