import ipaddress
import socket
import re

def validate_ip(addr):
    try:
        if re.search(r"/", addr):
            ipaddress.ip_network(addr)
        else:
            ipaddress.ip_address(addr)
        return True
    except Exception:
        return False

def ip_in_network(addr, networks):
    if isinstance(networks, str):
        networks = [networks]

    if re.search(":", addr):
        net = ipaddress.IPv6Network
        v = 6
    else:
        net = ipaddress.IPv4Network
        v = 4

    addr = net(addr)

    for network in networks:
        n6 = re.search(":", network)

        if (n6 and v == 6) or (not n6 and v == 4):
            n = net(network)
            if n.overlaps(addr):
                return True

    return False

def get_ips_by_hostname(hostname, family=None):
    """
    Return the IP address of a hostname.
        ip4 = plugin.get_ip_by_hostname(
            family="v4", hostname="www.bloonix.org")
        ip6 = plugin.get_ip_by_hostname(
            family="v6", hostname="www.bloonix.org")
        ipX = plugin.get_ip_by_hostname(
            family="any", hostname="www.bloonix.org")
    "any" tries at first to get a ipv4 address, then a ipv6 address.
    The method returns 'False' if the hostname couldn't be resolved.
    """

    if family is None or family == "any":
        ips = get_ips_by_hostname(family="v4", hostname=hostname)
        ips += get_ips_by_hostname(family="v6", hostname=hostname)
        return ips

    if family == "v4":
        if re.search(r"^\d+\.\d+\.\d+\.\d+\Z", hostname):
            return [hostname]
        af_inet = socket.AF_INET
    elif family == "v6":
        if ":" in hostname:
            return [hostname]
        af_inet = socket.AF_INET6
    else:
        raise Exeption("invalid ip version: %s" % family)

    ips = []

    try:
        ret = socket.getaddrinfo(
            hostname, None, af_inet,
            type=0, proto=0, flags=0)
        for r in ret:
            if r[4][0] not in ips:
                ips.append(r[4][0])
    except Exception:
        pass

    return ips

def get_ip_by_hostname(hostname, family=None):
    ips = get_ips_by_hostname(hostname, family)
    if len(ips):
        return ips[0]
    return None
