import bloonix.plugin.base
import bloonix.plugin.has_snmp
import easysnmp
import re

class Check(bloonix.plugin.base.Check, bloonix.plugin.has_snmp.HasSNMP):
    def snmp_walk(self, oid, empty_ok=False):
        ret = {}
        s = self.__start_snmp_session()
        for var in s.walk(oid):
            index = "%s.%s" % (var.oid, var.oid_index)
            index = re.sub(r"^\.", "", index)
            value = self.__get_snmp_value(var)
            if value == None:
                if empty_ok == False:
                    self.exit(
                        status="CRITICAL",
                        message="no such object")
                return None
            ret[index] = value
        return ret

    def snmp_get(self, oid, empty_ok=False):
        s = self.__start_snmp_session()
        try:
            var = s.get(oid)
        except easysnmp.EasySNMPNoSuchNameError:
            self.exit(
                status="UNKNOWN",
                message="snmp get returns multiple results")

        value = self.__get_snmp_value(var)
        if value == None:
            if empty_ok == False:
                self.exit(
                    status="CRITICAL",
                    message="no such object")
            return None
        return value

    def __get_snmp_value(self, var):
        if var.value == None:
            return None
        if (var.snmp_type == "INTEGER32"
                or var.snmp_type == "INTEGER"
                or var.snmp_type == "COUNTER32"
                or var.snmp_type == "COUNTER64"
                or var.snmp_type == "GAUGE32"
                or var.snmp_type == "UNSIGNED32"
                or var.snmp_type == "TIMETICKS"):
            return int(var.value)
        return str(var.value)

    def __start_snmp_session(self):
        if hasattr(self, "__snmp_session"):
            return self.__snmp_session
        if self.option["snmp-version"] == "1":
            version = 1
        elif self.option["snmp-version"] == "2c":
            version = 2
        self.__snmp_session = easysnmp.Session(
            version=version,
            community=self.option["community"],
            hostname=self.option["host"],
            remote_port=self.option["port"],
            use_numeric=True)
        return self.__snmp_session
