import bloonix.plugin.base
import bloonix.plugin.has_snmp
import netsnmp

class Check(bloonix.plugin.base.Check, bloonix.plugin.has_snmp.HasSNMP):
    def snmp_walk(self, oid, empty_ok=False):
        ret = {}
        s = self.__start_snmp_session()
        bind = netsnmp.Varbind(".%s" % oid)
        var_list = netsnmp.VarList(bind)
        s.walk(var_list)
        for var in var_list:
            index = "%s.%s" % (var.tag[1:], var.iid)
            value = self.__get_snmp_value(var)
            if value == None:
                if empty_ok == False:
                    self.exit(
                        status="CRITICAL",
                        message="no such object")
                return None
            ret[index] = value
        return ret

    def snmp_get(self, oid, empty_ok=False):
        s = self.__start_snmp_session()
        bind = netsnmp.Varbind(".%s" % oid)
        var_list = netsnmp.VarList(bind)
        s.get(var_list)
        if len(var_list) > 1:
            self.exit(
                status="UNKNOWN",
                message="snmp get returns multiple results")
        var = var_list[0]
        value = self.__get_snmp_value(var_list[0])
        if value == None:
            if empty_ok == False:
                self.exit(
                    status="CRITICAL",
                    message="no such object")
            return None
        return value

    def __get_snmp_value(self, var):
        if var.val == None:
            return None
        if (var.type == "INTEGER32"
                or var.type == "INTEGER"
                or var.type == "COUNTER32"
                or var.type == "COUNTER64"
                or var.type == "GAUGE32"
                or var.type == "UNSIGNED32"
                or var.type == "TIMETICKS"):
            return int(var.val)
        return str(var.val)

    def __start_snmp_session(self):
        if hasattr(self, "__snmp_session"):
            return self.__snmp_session
        if self.option["snmp-version"] == "1":
            version = 1
        elif self.option["snmp-version"] == "2c":
            version = 2
        self.__snmp_session = netsnmp.Session(
            Version=version,
            Community=self.option["community"],
            DestHost=self.option["host"],
            RemotePort=self.option["port"],
            UseNumeric=1,
        )
        return self.__snmp_session
