"""
This module is based on pysnmp 4.x.x.
Debian Stretch, Buster, Bullseye
python3-pysnmp4
"""
import bloonix.plugin.base
import bloonix.plugin.has_snmp
import pysnmp.hlapi as snmp
from pysnmp.proto.rfc1905 import NoSuchObject

class Check(bloonix.plugin.base.Check, bloonix.plugin.has_snmp.HasSNMP):
    def snmp_walk(self, oid, empty_ok=False):
        return self.__snmp_request(oid, snmp.nextCmd, empty_ok)

    def snmp_get(self, oid, empty_ok=False):
        res = self.__snmp_request(oid, snmp.getCmd, empty_ok)
        if empty_ok is True and res is None:
            return None
        if oid in res:
            return res[oid]
        return None

    def __snmp_request(self, oid, snmp_object, empty_ok=False):
        data = {}

        if self.option["snmp-version"] == "1":
            version = 0
        elif self.option["snmp-version"] == "2c":
            version = 1

        response = snmp_object(
            snmp.SnmpEngine(maxMessageSize=65535),
            snmp.CommunityData(self.option["community"], mpModel=version),
            snmp.UdpTransportTarget((self.option["host"], self.option["port"])),
            snmp.ContextData(),
            snmp.ObjectType(snmp.ObjectIdentity(oid)),
            lookupMib=False,
            lexicographicMode=False
        )

        for item in response:
            error_indication, error_status, error_index, var_binds = item

            if error_indication:
                self.exit(
                    status="CRITICAL",
                    message="SNMP error: %s" % error_indication)
            if error_status:
                self.exit(
                    status="CRITICAL",
                    message="SNMP status: %s" % error_status)

            oid, value = var_binds[0]
            oid = str(oid)

            if isinstance(value, NoSuchObject):
                if empty_ok is True:
                    return None
                self.exit(
                    status="CRITICAL",
                    message="no such object")

            if (isinstance(value, snmp.Integer32) or
                    isinstance(value, snmp.Integer) or
                    isinstance(value, snmp.Counter32) or
                    isinstance(value, snmp.Counter64) or
                    isinstance(value, snmp.Gauge32) or
                    isinstance(value, snmp.Unsigned32) or
                    isinstance(value, snmp.TimeTicks)):
                data[oid] = int(value)
            else:
                data[oid] = value.prettyPrint()

        if len(data) == 0:
            if empty_ok is True:
                return None
            self.exit(
                status="CRITICAL",
                message="oid %s not found" % oid)

        return data
