import os
import sys
import pwd
import grp
from bloonix.exception import BloonixError

"""
hang_up() and switch_to() only switch the user and group
if they are not set to None. Please use switch_user() and
switch_group() If you want to take care that either user
and group are switched or a exception is triggered.
"""

def hang_up(user=None, group=None, pid_file=None):
    setsid()
    change_directory()

    if pid_file is not None:
        create_pid_file(pid_file)

    switch_to(user, group)

def switch_to(user=None, group=None):
    if group is not None:
        switch_group(group, user)
    if user is not None:
        switch_user(user)

def switch_user(user):
    cur_uid = os.geteuid()
    set_uid = pwd.getpwnam(user).pw_uid
    if set_uid != cur_uid:
        check_uid()
        os.setuid(set_uid)

def switch_group(group, user=None):
    cur_gid = os.getegid()
    set_gid = grp.getgrnam(group).gr_gid
    if user is not None:
        # put the user also into supplementary groups
        os.initgroups(user, set_gid)
    if set_gid != cur_gid:
        check_uid()
        os.setgid(set_gid)

def setsid():
    pid = os.fork()
    if pid:
        os._exit(0)
    os.setsid()

def check_uid():
    if os.geteuid() != 0:
        raise BloonixError("you need root permission to run this program")

def change_directory(directory="/"):
    os.chdir(directory)

def create_pid_file(pid_file):
    f = open(pid_file, "w")
    f.write(str(os.getpid()))
    f.close()

def redirect_output(to=os.devnull):
    sys.stdout = open(to, 'w')
    sys.stderr = open(to, 'w')
    sys.stdin = open(os.devnull, 'r')

def get_uid(user):
    return pwd.getpwnam(user).pw_uid

def get_gid(group):
    return grp.getgrnam(group).gr_gid
