import redis
import time
from bloonix.logger import logger

class Redis:
    def __init__(self, **config):
        host = config.get("host", "127.0.0.1")
        port = config.get("port", 6379)
        db = int(config.get("db", 0))
        self.redis = redis.Redis(
            host=host,
            port=port,
            db=db,
            charset="utf-8",
            decode_responses=True)
        self.log = logger("bloonix")

    def set(self, key, value):
        return self.redis.set(key, value)

    def get(self, key, default=None):
        v = self.redis.get(key)
        if v is None:
            return default
        return v

    def delete(self, key):
        return self.redis.delete(key)

    def push(self, queue_name, value):
        return self.redis.rpush(queue_name, value)

    def pull(self, queue_name, count=None):
        if count:
            return self.redis.lpop(queue_name, count) # returns a array
        return self.redis.lpop(queue_name) # returns a string

    def pull_wait(self, queue_name, timeout=1):
        return self.redis.blpop(queue_name, timeout)

    def get_range(self, queue_name, start=0, stop=-1):
        return self.redis.lrange(queue_name, start, stop)

    def remove(self, queue_name, string, count=0):
        return self.redis.lrem(queue_name, count, string)

    def get_keys(self, key):
        return self.redis.keys(key)

    def flush(self):
        return self.redis.flushdb()

    def uptime(self):
        info = self.redis.info()
        return int(info["uptime_in_seconds"])

    def llen(self, queue_name):
        return self.redis.llen(queue_name)
