"""
Regexes. Not compiled. No captures. No more to say.
"""

IS_BOOL_NUMBER = r"^[01]\Z"
IS_BOOL_STRING = r"^(?:yes|no)\Z"

YEAR_BASE = r"(?:-{0,1}\d+)"
YEAR = r"^%s\Z" % YEAR_BASE

MONTH_BASE = r"(?:0[1-9]|1[0-2])"
MONTH = r"^%s\Z" % MONTH_BASE

DAY_BASE = r"(?:0[1-9]|[1-2][0-9]|3[0-1])"
DAY = r"^%s\Z" % DAY_BASE

MONTH_AND_DAY_BASE = (
    r"(?:"
        r"(?:(?:0?1|0?3|0?5|0?7|0?8|10|12)-(?:0[1-9]|[1-2][0-9]|3[0-1]))|"
        r"(?:(?:0?4|0?6|0?9|11)-(?:0[1-9]|[1-2][0-9]|30))|"
        r"(?:0?2-(?:0[1-9]|[1-2][0-9]))|"
    r")"
)
MONTH_AND_DAY = r"^%s\Z" % MONTH_AND_DAY_BASE

HOUR_BASE = r"(?:[0-1][0-9]|2[0-3])"
HOUR = r"^%s\Z" % HOUR_BASE

MINUTE_BASE = r"(?:[0-5][0-9])"
MINUTE = r"^%s\Z" % MINUTE_BASE

SECOND_BASE = MINUTE_BASE
SECOND = r"^%s\Z" % SECOND_BASE

WEEKDAY_BASE = (
    r"(?:"
    r"[Mm]on(?:day){0,1}|"
    r"[Tt]ue(?:sday){0,1}|"
    r"[Ww]ed(?:nesday){0,1}|"
    r"[Tt]hu(?:rsday){0,1}|"
    r"[Ff]ri(?:day){0,1}|"
    r"[Ss]at(?:urday){0,1}|"
    r"[Ss]un(?:day){0,1}"
    r")"
)

MONTH_NAME_BASE = (
    r"(?:"
        r"[Jj]an(?:uary){0,1}|"
        r"[Ff]eb(?:ruary){0,1}|"
        r"[Mm]ar(?:ch){0,1}|"
        r"[Aa]pr(?:il){0,1}|"
        r"[Mm]ay|"
        r"[Jj]un(?:e){0,1}|"
        r"[Jj]ul(?:y){0,1}|"
        r"[Aa]ug(?:ust){0,1}|"
        r"[Ss]ep(?:tember){0,1}|"
        r"[Oo]ct(?:ober){0,1}|"
        r"[Nn]ov(?:ember){0,1}|"
        r"[Dd]ec(?:ember){0,1}"
    r")"
)

MONTH_NAME = r"^%s\Z" % MONTH_NAME_BASE
YEAR_MONTH = r"^%s-%s\Z" % (YEAR_BASE, MONTH_BASE)
HOUR_MIN = r"^%s:%s\Z" % (HOUR_BASE, MINUTE_BASE)
DATE = r"^%s-%s-%s\Z" % (YEAR_BASE, MONTH_BASE, DAY_BASE)
TIME = r"^%s:%s:%s\Z" % (HOUR_BASE, MINUTE_BASE, SECOND_BASE)
DATETIME = r"^%s-%s\s+%s:%s:%s\Z" % (
    YEAR_BASE, MONTH_AND_DAY_BASE, HOUR_BASE, MINUTE_BASE, SECOND_BASE)
DATEHOURMIN = r"%s-%s\s+%s:%s\Z" % (
    YEAR_BASE, MONTH_AND_DAY_BASE, HOUR_BASE, MINUTE_BASE)

PORT_BASE = (
    r"(?:"
        r"6553[0-5]|"       # 65530 - 65535
        r"655[0-2][0-9]|"   # 65500 - 65529
        r"65[0-4][0-9]{2}|" # 65000 - 65499
        r"6[0-4][0-9]{3}|"  # 60000 - 64999
        r"[1-5][0-9]{4}|"   # 10000 - 59999
        r"[1-9][0-9]{0,3}"  # 1 - 9999
    r")"
)

PORT = r"^%s\Z" % PORT_BASE

IPV4_BASE = (
    r"(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|0{0,1}[1-9][0-9]|0{0,2}[1-9])\."
    r"(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|0{0,1}[1-9][0-9]|0{0,2}[0-9])\."
    r"(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|0{0,1}[1-9][0-9]|0{0,2}[0-9])\."
    r"(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|0{0,1}[1-9][0-9]|0{0,2}[0-9])"
)

NET32_BASE = r"(?:[0-9]|[12][0-9]|3[012])"
IPV4NET_BASE = r"%s/%s" % (IPV4_BASE, NET32_BASE)

IPV4 = r"^%s\Z" % IPV4_BASE
IPV4NET = r"^%s\Z" % IPV4NET_BASE

IPV6_PART = r"(?:[0-9A-Fa-f]{1,4}|[0-9A-Fa-f])"

IPV6_BASE = (
    r"(?:"
        r"(?:%s:){7}%s"
        r"|(?:%s:){6}:%s"
        r"|(?:%s:){5}(?::%s){2}"
        r"|(?:%s:){4}(?::%s){3}"
        r"|(?:%s:){3}(?::%s){4}"
        r"|(?:%s:){2}(?::%s){5}"
        r"|%s:(?::%s){6}"
        r"|(?:%s:){5}:%s"
        r"|(?:%s:){4}(?::%s){2}"
        r"|(?:%s:){2}(?::%s){4}"
        r"|%s:(?::%s){5}"
        r"|(?:%s:){4}:%s"
        r"|%s:(?::%s){4}"
        r"|(?:%s:){1,3}(?::%s){1,3}"
        r"|:(?::%s){1,7}"
        r"|(?:%s:){1,7}:"
        r"|::"
    r")"
    % (
        IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART,
        IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART,
        IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART,
        IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART,
        IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART,
        IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART, IPV6_PART
    )
)

NET128_BASE = r"(?:[0-9]|[1-9][0-9]|1[01][0-9]|12[0-8])"
IPV6NET_BASE = r"%s/%s" % (IPV6_BASE, NET128_BASE)

IPV6 = r"^%s\Z" % IPV6_BASE
IPV6NET = r"^%s\Z" % IPV6NET_BASE
IPADDR = r"^(?:%s|%s)\Z" % (IPV4_BASE, IPV6_BASE)
IPADDR_ALL = r"^(?:all|%s|%s)\Z" % (IPV4_BASE, IPV6_BASE)
IPADDRNET = r"^(?:%s|%s)\Z" % (IPV4NET_BASE, IPV6NET_BASE)
IPADDRNET_ALL = r"^(?:all|%s|%s)\Z" % (IPV4NET_BASE, IPV6NET_BASE)

HOSTNAME_BASE = r"(?=.{1,255})[a-zA-Z0-9]{1,63}(?:[-.][a-zA-Z0-9]{1,63})*"
HOSTNAME = r"^%s\Z" % HOSTNAME_BASE

HOST_BASE = "(?:%s|%s|%s)" % (HOSTNAME_BASE, IPV4_BASE, IPV6_BASE)
HOST = r"^%s\Z" % HOST_BASE
HOSTPORT_BASE = r"(?:%s|%s|\[%s\]):%s" % (
    HOSTNAME_BASE, IPV4_BASE, IPV6_BASE, PORT_BASE)
HOSTPORT = r"^%s\Z" % HOSTPORT_BASE

# Captures:
# 1 = protocol
# 2 = HOSTNAME + PORT
# 3 = path + query string
HTTP_URL_BASE = (
    r"(?:"
        r"(?:https{0,1})"       # protocol
        r"://"                  # sep
        r"(?:"
            r"(?:%s|%s|\[%s\])" # HOSTNAME/ip4v/IPV6
            r"(?::%s){0,1}"     # PORT
        r")"
        r"(?:"
            r"(?:/|\?)"         # sep
            r"[^\r\n\s\0`'\\]*" # DON'T REMOVE APOSTROPHE!
        r"){0,1}"               # the part after the HOSTNAME is optional
    r")"                        # min and max len of the complete url
    % (HOSTNAME_BASE, IPV4_BASE, IPV6_BASE, PORT_BASE)
)

# http://test.test:80/
# http://127.0.0.0:80/
# http://[::1]:80/
HTTP_URL = r"^(?=.{8,2000})(?:%s)\Z" % HTTP_URL_BASE

# I disagree with rfc822. It allows mail addresses like
#   user@[IPv6:2001:db8:1ff::a0b:dbd0]
# or
#   "very.(),:;<>[]\".VERY.\"very@\\ \"very\".unusual"@strange.example.com
# or
#   "()<>[]:,;@\\\"!#$%&'*+-/=?^_`{}| ~.a"@example.org
#
# For this reason I wrote a simple mail parser with higher restrictions
# to allowed signs in the name and host part.
#   - only the signs a-z, A-Z, 0-9 and .-+_ are allowed in the name part
#   - doubled signs of .-+_ are not allowed in the name part
#   - only the signs a-z, A-Z, 0-9 and .- are allowed in the HOST part
#   - doubled signs of . are not allowed in the HOST part
#   - the name part must begin and end with a-z, A-Z or 0-9
EMAIL_BASE = (
    r"[a-zA-Z0-9]+(?:[\.\-\+_][a-zA-Z0-9]+)*" # this is the name part
    r"@"                                    # delimiter
    r"%s"                                   # the HOSTNAME
    % HOSTNAME_BASE
)
EMAIL = r"^%s\Z" % EMAIL_BASE

# /Foo/Bar/Baz - not to be confused with python class path.
CLASS_PATH = r"^(?:/[^/]+){0,}\Z"
