#!/usr/bin/python3

import bloonix.json as json
import os
import re
import signal
import sys
import time

todo = {}
args = list(sys.argv)
progname = args.pop(0)

while len(args):
    arg = args.pop(0)
    if re.search(r"=", arg):
        key, value = re.split("=", arg)
        todo[key] = value
    else:
        todo[arg] = True

message = {
    "pid": os.getpid(),
    "time": time.strftime("%Y-%m-%d %H:%M:%S"),
    "unix_time": int(time.time())
}

def sig_hup_handler(signum, frame):
    message["signal"] = "hup"

def sig_term_handler(signum, frame):
    message["signal"] = "term"

signal.signal(signal.SIGHUP, sig_hup_handler)
signal.signal(signal.SIGTERM, sig_term_handler)

if "stdin" in todo:
    message["stdin"] = sys.stdin.readlines()[0]
    message["stdin"].rstrip()

if "sleep" in todo:
    message["sleep"] = todo["sleep"]
    time.sleep(int(todo["sleep"]))

if "stdout" in todo:
    stdout = {"stdxxx": "stdout"}
    stdout.update(message)
    print(json.dumps(stdout), end="")

if "stderr" in todo:
    stderr = {"stdxxx": "stderr"}
    stderr.update(message)
    print(json.dumps(stderr), file=sys.stderr, end="")

if "size" in todo:
    print("X" * int(todo["size"]))

if "echo" in todo:
    print(todo["echo"], end="")

if "echo_to_stderr" in todo:
    print(todo["echo_to_stderr"], file=sys.stderr, end="")

if "exit" in todo:
    sys.exit(int(todo["exit"]))

sys.exit(0)
