#!/usr/bin/python3

import bloonix.json as json
import os
import re
import sys
import unittest
from bloonix.exception import BloonixError
from bloonix.config import parse_file

class Bloonix:
    config = None


class TestRunCmd(unittest.TestCase):
    def test_000_parse(self):
        Bloonix.config = parse_file("etc/config/main.conf")
        self.assertTrue(type(Bloonix.config) is dict)

    def test_dot(self):
        self.assertTrue(Bloonix.config["test.dot"] == "value.dot")

    def test_minus(self):
        self.assertTrue(Bloonix.config["test-minus"] == "value-minus")

    def test_underscore(self):
        self.assertTrue(Bloonix.config["test_underscore"] == "value_underscore")

    def test_comment1(self):
        self.assertTrue(Bloonix.config["test_comment_1"] == "# value")

    def test_comment2(self):
        self.assertTrue(Bloonix.config["test_comment_2"] == "# value")

    def test_single_quotes(self):
        self.assertTrue(Bloonix.config["test_single_quotes"] == '"value"')

    def test_double_quotes(self):
        self.assertTrue(Bloonix.config["test_double_quotes"] == "'value'")

    def test_whitespaces(self):
        self.assertTrue(Bloonix.config["test_whitespaces"] == "  value  ")

    def test_multiline_simple(self):
        self.assertTrue(Bloonix.config["test_multiline_simple"] == "a b cd e fg h i")

    def test_multiline_complex(self):
        self.assertTrue(Bloonix.config["test_multiline_complex"] == " a b c  d e f  g h i ")

    def test_section(self):
        self.assertTrue(type(Bloonix.config["section"]) is dict)
        self.assertTrue(Bloonix.config["section"]["key"] == "value")

    def test_sub_section(self):
        self.assertTrue(type(Bloonix.config["section"]["sub_section"]) is dict)
        self.assertTrue(Bloonix.config["section"]["sub_section"]["key"] == "value")

    def test_sub_section_list(self):
        self.assertTrue(type(Bloonix.config["section"]["sub_section"]["test_array"]) is list)
        self.assertTrue(Bloonix.config["section"]["sub_section"]["test_array"][0] == "value_1")
        self.assertTrue(Bloonix.config["section"]["sub_section"]["test_array"][1] == "value_2")

    def test_section_conf_d(self):
        self.assertTrue(type(Bloonix.config["section"]["conf_d_section"]) is dict)
        self.assertTrue(Bloonix.config["section"]["conf_d_section"]["key"] == "value")

    def test_conf_d(self):
        self.assertTrue(type(Bloonix.config["conf_d_section"]) is dict)
        self.assertTrue(Bloonix.config["conf_d_section"]["key"] == "value")

    def test_err_01_multiline(self):
        self.assertRaises(
            BloonixError, parse_file,
            "etc/config/err-01-multiline.conf"
        )

    def _test_err_02_multiline(self):
        self.assertRaises(
            BloonixError, parse_file,
            "etc/err-02-multiline.conf"
        )

    def _test_err_03_multiline(self):
        self.assertRaises(
            BloonixError, parse_file,
            "etc/err-03-multiline.conf"
        )

    def _test_err_unclosed_section(self):
        self.assertRaises(
            BloonixError, parse_file,
            "etc/err-unclosed-section.conf"
        )

    def _test_err_unopened_section(self):
        self.assertRaises(
            BloonixError, parse_file,
            "etc/err-unopened-section.conf"
        )


unittest.main(verbosity=2)
