#!/usr/bin/python3

import re
import unittest
import socket
from bloonix.http.client import request

class TestHTTPClient(unittest.TestCase):
    def test_simple(self):
        ret = request(url="https://js.bloonix.dev/")
        self.assertTrue(ret.status == 200)
        self.assertTrue(
            ret.headers["content-type"] == "text/html; charset=utf-8")
        self.assertTrue(re.search(r"Hello World", ret.content))

    def test_auth_basic(self):
        ret = request(url="https://js.bloonix.dev/auth-basic")
        self.assertTrue(ret.status == 401)
        ret = request(
            url="https://js.bloonix.dev/auth-basic",
            auth_basic="foo:bar")
        self.assertTrue(ret.status == 200)

    def test_user_agent(self):
        ret = request(
            url="https://js.bloonix.dev/user-agent",
            user_agent="bloonix-httpclient")
        self.assertTrue(ret.status == 200)
        self.assertTrue(ret.content == "bloonix-httpclient")

    def test_max_read_len(self):
        ret = request(url="https://js.bloonix.dev/", max_read_len=10)
        self.assertTrue(ret.has_failed == True)
        self.assertTrue(str(ret.error) == "body too long - max 10 bytes allowed")

    def test_timeout(self):
        ret = request(url="https://js.bloonix.dev/sleep", timeout=3)
        self.assertTrue(ret.has_failed == True)
        self.assertTrue(str(ret.error) == "The read operation timed out")


unittest.main(verbosity=2)
