#!/usr/bin/python3

import re
import unittest
from bloonix.http.libcurl import request

class TestLibCURL(unittest.TestCase):
    def test_simple(self):
        res = request(url="https://js.bloonix.dev/")
        self.assertTrue(res.version == "2")
        self.assertTrue(res.status == 200)
        self.assertTrue(
            res.headers["content-type"] == "text/html; charset=utf-8")
        self.assertTrue(res.encoding == "utf-8")
        self.assertTrue(re.search(r"Hello World", res.content))

    def test_auth_basic(self):
        res = request(url="https://js.bloonix.dev/auth-basic")
        self.assertTrue(res.status == 401)
        res = request(
            url="https://js.bloonix.dev/auth-basic",
            auth_basic="foo:bar")
        self.assertTrue(res.status == 200)

    def test_user_agent(self):
        res = request(
            url="https://js.bloonix.dev/user-agent",
            user_agent="bloonix-libcurl")
        self.assertTrue(res.status == 200)
        self.assertTrue(res.content == "bloonix-libcurl")

    def test_max_read_len(self):
        res = request(url="https://js.bloonix.dev/too-long-response")
        self.assertTrue(res.has_failed == True)
        self.assertTrue(
            res.error == "(23, 'Failure writing output to destination')")

    def test_timeout(self):
        res = request(url="https://js.bloonix.dev/sleep", timeout=3)
        self.assertTrue(res.has_failed == True)
        self.assertTrue(re.search(r"operation timed out", res.error))


unittest.main(verbosity=2)
