#!/usr/bin/python3

import unittest
from bloonix.http.utils import (
    quote,
    quote_url_path,
    quote_string,
    quote_data,
    parse_url,
    unparse_url_quoted,
    header_to_dict)

class TestLibCURL(unittest.TestCase):
    def test_quote(self):
        return

    def test_quote_url_path(self):
        quoted = quote_url_path("/foo/bär")
        self.assertTrue(quoted == "/foo/b%C3%A4r")

    def test_quote_string(self):
        quoted = quote_string("foo=bär&föo=bar")
        self.assertTrue(quoted == "foo=b%C3%A4r&f%C3%B6o=bar")

    def test_quote_data(self):
        quoted = quote_data({"foo": "bär", "föo": "bar"})
        self.assertTrue(quoted == "foo=b%C3%A4r&f%C3%B6o=bar")

    def test_parse_url(self):
        scheme, host, port, path, qs, frag = parse_url(
            "https://[::1]:8443/?param=value#frag")
        self.assertTrue(scheme == "https")
        self.assertTrue(host == "[::1]")
        self.assertTrue(port == 8443)
        self.assertTrue(path == "/")
        self.assertTrue(qs == "param=value")
        self.assertTrue(frag == "frag")

    def test_unparse_url_quoted_default_port(self):
        scheme, host, port, path, qs, frag = parse_url(
            "https://[::1]:443/path?param=value#frag")
        url = unparse_url_quoted(
            scheme, host, port, path, qs, frag)
        self.assertTrue(
            url == "https://[::1]/path?param=value#frag")

    def test_unparse_url_quoted(self):
        scheme, host, port, path, qs, frag = parse_url(
            "https://[::1]:8443/päth?päram=valüe#frag")
        url = unparse_url_quoted(
            scheme, host, port, path, qs, frag)
        self.assertTrue(
            url == "https://[::1]:8443/p%C3%A4th?p%C3%A4ram=val%C3%BCe#frag")


unittest.main(verbosity=2)
