#!/usr/bin/python3

import re
import unittest
from bloonix.exception import BloonixError
from bloonix.logger import logger

arr = []
layout = "%L %m"
i = 1

for level in ["debug", "info", "notice", "warning", "error", "critical"]:
    logger("test%s" % i).add(
        type="list",
        message_layout="%L %m",
        log_to=arr,
        level=level
    )
    i += 1

tx = logger("testx")
tx.add(type="list", message_layout="%L %m", log_to=arr)
tx.add(type="list", message_layout="%L %m", log_to=arr)
tx.add(type="list", message_layout="%L %m", log_to=arr)

def log_to(to):
    logger(to).debug("test")
    logger(to).info("test")
    logger(to).notice("test")
    logger(to).warning("test")
    logger(to).error("test")
    logger(to).critical("test")


class TestRX(unittest.TestCase):
    global arr

    def test_debug(self):
        log_to("test1")
        for level in ["CRITICAL", "ERROR", "WARNING", "NOTICE", "INFO", "DEBUG"]:
            self.assertTrue(arr.pop() == "%s test" % level)
        self.assertTrue(len(arr) == 0)

    def test_info(self):
        log_to("test2")
        for level in ["CRITICAL", "ERROR", "WARNING", "NOTICE", "INFO"]:
            self.assertTrue(arr.pop() == "%s test" % level)
        self.assertTrue(len(arr) == 0)

    def test_notice(self):
        log_to("test3")
        for level in ["CRITICAL", "ERROR", "WARNING", "NOTICE"]:
            self.assertTrue(arr.pop() == "%s test" % level)
        self.assertTrue(len(arr) == 0)

    def test_warning(self):
        log_to("test4")
        for level in ["CRITICAL", "ERROR", "WARNING"]:
            self.assertTrue(arr.pop() == "%s test" % level)
        self.assertTrue(len(arr) == 0)

    def test_error(self):
        log_to("test5")
        self.assertTrue(arr.pop() == "CRITICAL test")
        self.assertTrue(arr.pop() == "ERROR test")
        self.assertTrue(len(arr) == 0)

    def test_critical(self):
        log_to("test6")
        self.assertTrue(arr.pop() == "CRITICAL test")
        self.assertTrue(len(arr) == 0)

    def test_dump(self):
        logger("test3").info({"foo":"bar"}, dump=True)
        logger("test3").notice({"foo":"bar"}, dump=True)
        self.assertTrue(re.search('NOTICE.*"foo":.*"bar"', arr.pop(), re.S))

    def test_log(self):
        logger("test3").log({"foo":"bar"}, level="info", dump=True)
        logger("test3").log({"foo":"bar"}, level="notice", dump=True)
        self.assertTrue(re.search('NOTICE.*"foo":.*"bar"', arr.pop(), re.S))

    def test_is_debug(self):
        self.assertTrue(logger("test1").is_debug() is True)
        self.assertTrue(logger("test1").is_info() is True)
        self.assertTrue(logger("test1").is_notice() is True)
        self.assertTrue(logger("test1").is_warning() is True)
        self.assertTrue(logger("test1").is_error() is True)
        self.assertTrue(logger("test1").is_critical() is True)

    def test_is_info(self):
        self.assertTrue(logger("test2").is_debug() is False)
        self.assertTrue(logger("test2").is_info() is True)
        self.assertTrue(logger("test2").is_notice() is True)
        self.assertTrue(logger("test2").is_warning() is True)
        self.assertTrue(logger("test2").is_error() is True)
        self.assertTrue(logger("test2").is_critical() is True)

    def test_is_notice(self):
        self.assertTrue(logger("test3").is_debug() is False)
        self.assertTrue(logger("test3").is_info() is False)
        self.assertTrue(logger("test3").is_notice() is True)
        self.assertTrue(logger("test3").is_warning() is True)
        self.assertTrue(logger("test3").is_error() is True)
        self.assertTrue(logger("test3").is_critical() is True)

    def test_is_warning(self):
        self.assertTrue(logger("test4").is_debug() is False)
        self.assertTrue(logger("test4").is_info() is False)
        self.assertTrue(logger("test4").is_notice() is False)
        self.assertTrue(logger("test4").is_warning() is True)
        self.assertTrue(logger("test4").is_error() is True)
        self.assertTrue(logger("test4").is_critical() is True)

    def test_is_error(self):
        self.assertTrue(logger("test5").is_debug() is False)
        self.assertTrue(logger("test5").is_info() is False)
        self.assertTrue(logger("test5").is_notice() is False)
        self.assertTrue(logger("test5").is_warning() is False)
        self.assertTrue(logger("test5").is_error() is True)
        self.assertTrue(logger("test5").is_critical() is True)

    def test_is_critical(self):
        self.assertTrue(logger("test6").is_debug() is False)
        self.assertTrue(logger("test6").is_info() is False)
        self.assertTrue(logger("test6").is_notice() is False)
        self.assertTrue(logger("test6").is_warning() is False)
        self.assertTrue(logger("test6").is_error() is False)
        self.assertTrue(logger("test6").is_critical() is True)

    def test_multiple(self):
        logger("testx").notice("test")
        self.assertTrue(len(arr) == 3)
        self.assertTrue(arr.pop() == "NOTICE test")
        self.assertTrue(arr.pop() == "NOTICE test")
        self.assertTrue(arr.pop() == "NOTICE test")
        self.assertTrue(len(arr) == 0)

    def test_message_patterns(self):
        layout = [
            "level=%L",         # 0
            "time=%T",          # 1
            "pid=%P",           # 2
            "host=%H",          # 3
            "user=%U",          # 4
            "group=%G",         # 5
            "caller=%C",        # 6
            "progname=%S",      # 7
            "shortname=%s",     # 8
            "runtime=%r",       # 9
            "measurement=%t",   # 10
            "message=%m",       # 11
            "percent=%%",       # 12
        ]

        logger("testp").add(
            type="list",
            log_to=arr,
            message_layout="%N".join(layout),
            prepare_multiline=False
        )

        logger("testp").notice("test")
        msg = arr.pop().split("\n")
        self.assertTrue(len(msg) == 13)
        self.assertTrue(re.search(r"^level=NOTICE", msg[0]))
        self.assertTrue(re.search(r"^time=\w+ \d+ \d+ \d+:\d+:\d+\Z", msg[1]))
        self.assertTrue(re.search(r"^pid=\d+\Z", msg[2]))
        self.assertTrue(re.search(r"^host=[\w\-.]+\Z", msg[3]))
        self.assertTrue(re.search(r"^user=\w+\Z", msg[4]))
        self.assertTrue(re.search(r"^group=\w+\Z", msg[5]))
        self.assertTrue(re.search(r"^caller=.+\Z", msg[6]))
        self.assertTrue(re.search(r"^progname=.*[/\\]test_logger\.py\Z", msg[7]))
        self.assertTrue(re.search(r"^shortname=test_logger\.py\Z", msg[8]))
        self.assertTrue(re.search(r"^runtime=\d+\.\d+\Z", msg[9]))
        self.assertTrue(re.search(r"^measurement=\d+\.\d+\Z", msg[10]))
        self.assertTrue(re.search(r"^message=test\Z", msg[11]))
        self.assertTrue(re.search(r"^percent=%\Z", msg[12]))

    def test_trace(self):
        logger("test1").info("test", add_trace=True)
        msg = arr.pop().split("\n")
        self.assertTrue(msg[0] == "INFO test")
        rx = re.compile(r"^\s+CALL\(\d+\): filename\(.+?\) function\(.+?\) line\(.+?\)")
        for i in range(1, len(msg) - 1):
            self.assertTrue(re.search(rx, msg[i]))

    def _config_tests(self, arr1, arr2, log):
        log.info("test arr1")
        log.notice("test arr1 and arr2")
        self.assertTrue(len(arr1) == 2)
        self.assertTrue(arr1[0] == "INFO test arr1")
        self.assertTrue(arr1[1] == "NOTICE test arr1 and arr2")
        self.assertTrue(len(arr2) == 1)
        self.assertTrue(arr2[0] == "NOTICE test arr1 and arr2")

    def test_config1(self):
        arr1 = []
        arr2 = []
        log = logger("test-config-1")
        log.config([
            {
                "type": "list",
                "message_layout": "%L %m",
                "log_to": arr1,
                "level": "info"
            },
            {
                "type": "list",
                "message_layout": "%L %m",
                "log_to": arr2,
                "level": "notice"
            }
        ])
        self._config_tests(arr1, arr2, log)

    def test_config2(self):
        arr1 = []
        arr2 = []
        log = logger("test-config-2")
        log.config({
            "list": [
                {
                    "message_layout": "%L %m",
                    "log_to": arr1,
                    "level": "info"
                },
                {
                    "message_layout": "%L %m",
                    "log_to": arr2,
                    "level": "notice"
                }
            ]
        })
        self._config_tests(arr1, arr2, log)

    def test_config2(self):
        arr1 = []
        arr2 = []
        log = logger("test-config-2")
        log.config({
            "list": {
                "message_layout": "%L %m",
                "log_to": arr1,
                "level": "info"
            }
        })
        log.config({
            "list": {
                "message_layout": "%L %m",
                "log_to": arr2,
                "level": "notice"
            }
        })
        self._config_tests(arr1, arr2, log)


unittest.main(verbosity=2)
