#!/usr/bin/python3

from bloonix.exception import BloonixError
import bloonix.timeperiod as timeperiod
import time
import unittest

class TestTemplate(unittest.TestCase):
    # 2016-04-04 was a Monday
    time1 = time.mktime(time.strptime("2016-04-04 16:59:59", "%Y-%m-%d %H:%M:%S"))
    time2 = time.mktime(time.strptime("2016-04-04 17:00:00", "%Y-%m-%d %H:%M:%S"))
    # US/Eastern -6h
    time3 = time.mktime(time.strptime("2016-04-04 22:59:59", "%Y-%m-%d %H:%M:%S"))
    time4 = time.mktime(time.strptime("2016-04-04 23:00:00", "%Y-%m-%d %H:%M:%S"))
    _debug = False

    def _simple_test(self, alias, ts):
        #if alias != "year_month":
        #    return
        for t in ts:
            if self._debug is True:
                print()
                print()
                print()
                print(timeperiod._parse(t))
                print()
                print()
                print(t, time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(self.time1)))
                print(timeperiod.check(t, self.time1))
                print()
                print()
                print(t, time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(self.time2)))
                print(timeperiod.check(t, self.time2))
                print()
                print()
            self.assertTrue(timeperiod._parse(t))
            self.assertTrue(timeperiod.check(t, self.time1))
            self.assertTrue(not timeperiod.check(t, self.time2))
            self.assertTrue(timeperiod.check(t, self.time3, "US/Eastern"))
            self.assertTrue(not timeperiod.check(t, self.time4, "US/Eastern"))

    def test_weekday(self):
        self._simple_test("weekday", [
            "Monday 09:00 - 16:59, 17:01 - 18:59",
            "Mon 09:00 - 16:59, 17:01 - 18:59",
            "Monday - Friday 09:00 - 16:59, 17:01 - 18:59",
            "Mon - Fri 09:00 - 16:59, 17:01 - 18:59"
        ])

    def test_month(self):
        self._simple_test("month", [
            "April 09:00 - 16:59, 17:01 - 18:59",
            "Apr 09:00 - 16:59, 17:01 - 18:59",
            "January - July 09:00 - 16:59, 17:01 - 18:59",
            "Jan - Jul 09:00 - 16:59, 17:01 - 18:59"
        ])

    def test_month_day(self):
        self._simple_test("month_day", [
            "April 04 09:00 - 16:59, 17:01 - 18:59",
            "Apr 04 09:00 - 16:59, 17:01 - 18:59",
            "January 01 - July 01 09:00 - 16:59, 17:01 - 18:59",
            "Jan 01 - Jul 01 09:00 - 16:59, 17:01 - 18:59"
        ])

    def test_year_month(self):
        self._simple_test("year_month", [
            "2016-04 09:00 - 16:59, 17:01 - 18:59",
            "2015-08 - 2016-05 09:00 - 16:59, 17:01 - 18:59"
        ])

    def test_date(self):
        self._simple_test("date", [
            "2016-04-04 09:00 - 16:59, 17:01 - 18:59",
            "2016-03-08 - 2016-04-12 09:00 - 16:59, 17:01 - 18:59"
        ])

    def _simple_format_test(self, alias, *ts):
        for f in ts:
            t = timeperiod._parse(f)
            self.assertTrue(t)
            self.assertTrue(t["alias"] == alias)

    def test_format_weekday(self):
        self._simple_format_test(
            "weekday",
            "Monday 09:00 - 16:59, 17:01 - 18:59",
            "Mon 09:00 - 16:59, 17:01 - 18:59",
            "Tuesday 09:00 - 16:59, 17:01 - 18:59",
            "Tue 09:00 - 16:59, 17:01 - 18:59",
            "Wednesday 09:00 - 16:59, 17:01 - 18:59",
            "Wed 09:00 - 16:59, 17:01 - 18:59",
            "Thursday 09:00 - 16:59, 17:01 - 18:59",
            "Thu 09:00 - 16:59, 17:01 - 18:59",
            "Friday 09:00 - 16:59, 17:01 - 18:59",
            "Fri 09:00 - 16:59, 17:01 - 18:59",
            "Saturday 09:00 - 16:59, 17:01 - 18:59",
            "Sat 09:00 - 16:59, 17:01 - 18:59",
            "Saturday 09:00 - 16:59, 17:01 - 18:59",
            "Sunday 09:00 - 16:59, 17:01 - 18:59",
            "Sun 09:00 - 16:59, 17:01 - 18:59"
        )

    def test_format_month(self):
        self._simple_format_test(
            "month",
            "January 09:00 - 16:59, 17:01 - 18:59",
            "Jan 09:00 - 16:59, 17:01 - 18:59",
            "February 09:00 - 16:59, 17:01 - 18:59",
            "Feb 09:00 - 16:59, 17:01 - 18:59",
            "March 09:00 - 16:59, 17:01 - 18:59",
            "Mar 09:00 - 16:59, 17:01 - 18:59",
            "April 09:00 - 16:59, 17:01 - 18:59",
            "Apr 09:00 - 16:59, 17:01 - 18:59",
            "June 09:00 - 16:59, 17:01 - 18:59",
            "Jun 09:00 - 16:59, 17:01 - 18:59",
            "July 09:00 - 16:59, 17:01 - 18:59",
            "Jul 09:00 - 16:59, 17:01 - 18:59",
            "August 09:00 - 16:59, 17:01 - 18:59",
            "Aug 09:00 - 16:59, 17:01 - 18:59",
            "September 09:00 - 16:59, 17:01 - 18:59",
            "Sep 09:00 - 16:59, 17:01 - 18:59",
            "October 09:00 - 16:59, 17:01 - 18:59",
            "Oct 09:00 - 16:59, 17:01 - 18:59",
            "November 09:00 - 16:59, 17:01 - 18:59",
            "Nov 09:00 - 16:59, 17:01 - 18:59",
            "December 09:00 - 16:59, 17:01 - 18:59",
            "Dec 09:00 - 16:59, 17:01 - 18:59"
        )

    def test_format_year_month(self):
        self._simple_format_test(
            "year_month",
            "2016-01 09:00 - 16:59, 17:01 - 18:59",
            "2016-02 09:00 - 16:59, 17:01 - 18:59",
            "2016-03 09:00 - 16:59, 17:01 - 18:59",
            "2016-04 09:00 - 16:59, 17:01 - 18:59",
            "2016-05 09:00 - 16:59, 17:01 - 18:59",
            "2016-06 09:00 - 16:59, 17:01 - 18:59",
            "2016-07 09:00 - 16:59, 17:01 - 18:59",
            "2016-08 09:00 - 16:59, 17:01 - 18:59",
            "2016-09 09:00 - 16:59, 17:01 - 18:59",
            "2016-10 09:00 - 16:59, 17:01 - 18:59",
            "2016-11 09:00 - 16:59, 17:01 - 18:59",
            "2016-12 09:00 - 16:59, 17:01 - 18:59"
        )

    def test_not_match(self):
        ts = [
            "Sunfoo 09:00 - 16:59, 17:01 - 18:59",
            "Dec 09:60 - 25:59, -0:01 - 18:-9"
            "2016-012 09:00 - 16:59, 17:01 - 18:59"
        ]
        for f in ts:
            self.assertTrue(not timeperiod._parse(f))


unittest.main(verbosity=2)
